#
# spec file for package helm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define git_commit %{version}

Name:           helm
Version:        2.8.2
Release:        lp150.4.2
Summary:        The Kubernetes Package Manager
License:        Apache-2.0
Group:          Development/Languages/Other
Url:            https://github.com/kubernetes/helm
Source:         %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  go1.10 >= 1.10.6
BuildRequires:  golang-packaging
BuildRequires:  xz
%{go_nostrip}
%{go_provides}

%description
Helm is a tool for managing Kubernetes charts. Charts are packages of pre-configured Kubernetes resources.

%prep
%setup -q -n %{name}-%{version}
tar xJf %{SOURCE1}
%{goprep} k8s.io/helm

%build
export GOPATH="%{_builddir}/go:$GOPATH"
GOBIN=$PWD/bin go install -tags '' -ldflags ' -X k8s.io/helm/pkg/version.Version=v%{version} -X k8s.io/helm/pkg/version.BuildMetadata= -X k8s.io/helm/pkg/version.GitCommit=%{git_commit} -X k8s.io/helm/pkg/version.GitTreeState=clean' k8s.io/helm/cmd/...

%install
%{__mkdir_p} %{buildroot}%{_bindir}
%{__install} -m755 bin/helm %{buildroot}/%{_bindir}/helm
%{__install} -m755 bin/tiller %{buildroot}/%{_bindir}/tiller

%files
%defattr(-,root,root,-)
%doc README.md LICENSE
%{_bindir}/helm
%{_bindir}/tiller

%changelog
* Thu Dec 13 2018 dorf@suse.com
- Require golang >= 1.10.6
  * bsc#1118897 CVE-2018-16873
    go#29230 cmd/go: remote command execution during "go get -u"
  * bsc#1118898 CVE-2018-16874
    go#29231 cmd/go: directory traversal in "go get" via curly braces in import paths
  * bsc#1118899 CVE-2018-16875
    go#29233 crypto/x509: CPU denial of service
* Tue Mar 13 2018 kmacinnes@suse.com
- Update to version 2.8.2:
  * Tiller should only enforce what we expect from Helm
  * Keepalive config should be independent of TLS
  * Bump client side grpc max msg size
  * Update deprecated grpc dial timeout
  * fix(tiller): Supersede multiple deployments (#3539)
  * replace FAILED deployments with `helm upgrade --install --force`
  * fix(helm): Don't crash in search if upper case chars are encountered.
  * fix helm init --wait
  * fix protoc
  * bump version to v2.8.2
* Thu Mar  1 2018 kmacinnes@suse.com
- Update to version 2.8.1
  * Includes fixes which allow Helm to correctly recognize
    resources created using the K8S 1.8/1.9 API namespaces
* Wed Dec 13 2017 jbonham@suse.com
- Update to version 2.7.2
  * fix missing ssl params
  See changelog in:
  https://github.com/kubernetes/helm/releases/tag/v2.7.2
* Thu Sep 28 2017 nmanchanda@suse.com
- Update to version 2.6.1
  * Remove facebookgo code
  See changelog in:
  https://github.com/kubernetes/helm/releases/tag/v2.6.1
* Mon Aug 28 2017 sleavens@suse.com
- Update to version 2.5.1
  * Fix bsc#1055480 - `helm init` now works
  * The deadlock problem with Tiller has been found and fixed
  * The `helm get manifest` and `helm get value` commands are now
    working properly
  * Plugins will now receive the correct value for `$HELM_HOME`
    regardless of how the home directory was set
  See changelog in:
  https://github.com/kubernetes/helm/releases/tag/v2.5.1
* Wed Apr  5 2017 jmassaguerpla@suse.com
- Fix GOPATH
* Tue Apr  4 2017 jmassaguerpla@suse.com
- Update to version 2.2.3
  * Helm has been moved to github/kubernetes/helm
  * Helm provides 2 binaries now: helm and tiller
  * go 1.7 is available now and with that version we can build all archs
    and we don't need to use gcc-go
  * the "symlinking trick into gopath" does not work anymore but instead
  we need to copy all files. Let's use the golang-packaging for this
  See changelog in:
  https://github.com/kubernetes/helm/releases/tag/v2.2.3
* Tue Apr 26 2016 fcastelli@suse.com
- Create initial package 0.6.0
